# firebird-uuid

[![PyPI - Version](https://img.shields.io/pypi/v/firebird-uuid.svg)](https://pypi.org/project/firebird-uuid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/firebird-uuid.svg)](https://pypi.org/project/firebird-uuid)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)

This package provides official tools for working with the OID namespace managed by the Firebird Project.

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)
- [Documentation](#documentation)

## Installation

```console
pip install firebird-uuid
```

## License

`firebird-uuid` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Documentation

The documentation for this package is available at [https://firebird-uuid.readthedocs.io](https://firebird-uuid.readthedocs.io)
